<template>
    <div class="home-container">
        <div style="height: 100%">
            <el-row class="homeCard">
                <div class="basic-line">
                    <span>规则名称：</span>
                    <el-input v-model="tableData.params.searchParams.ruleName" class="input-box" placeholder="规则名称"> </el-input>
                </div>
                <div class="basic-line">
                    <span>部门：</span>
                    <el-select v-model="tableData.params.searchParams.depId" clearable filterable class="input-box" placeholder="作业类型">
                        <el-option v-for="item in departmentList" :key="item.id" :label="item.department" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>作业类型：</span>
                    <el-select v-model="tableData.params.searchParams.workType" clearable filterable class="input-box" placeholder="作业类型">
                        <el-option v-for="item in workTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>作业等级：</span>
                    <el-select v-model="tableData.params.searchParams.workLevel" clearable filterable class="input-box" placeholder="作业等级">
                        <el-option v-for="item in workLevelList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div style="padding-bottom: 10px">
                    <el-button type="primary" @click="getApproveRule">查询</el-button>
                    <el-button plain @click="reset">重置</el-button>
                </div>
            </el-row>
            <div class="homeCard">
                <div class="main-card">
                    <el-row class="cardTop">
                        <el-col :span="24" class="mainCardBtn">
                            <el-button type="primary"  size="default" @click="openApproveRuleDialog('新增', {})">新建</el-button>
                            <el-button type="danger"  size="default" @click="deleteMoreApproveRule" plain>批量删除</el-button>
                        </el-col>
                    </el-row>
                    <el-table ref="multipleTableRef" :data="tableData.approveRuleData" style="width: 100%" height="calc(100% - 100px)" :header-cell-style="{ background: '#fafafa' }" @selection-change="handleSelectionChange">
                        <el-table-column type="selection" width="55" />
                        <el-table-column property="ruleName" label="任务名称" />
                        <el-table-column property="workType" label="作业类型">
                            <template slot-scope="scope">
                                <div v-for="item in workTypeList">
                                    <div v-if="scope.row.workType === item.id">
                                        <span>{{item.name}}</span>
                                    </div>
                                </div>
                            </template>
                        </el-table-column>
                        <el-table-column property="workLevel" label="作业等级">
                            <template slot-scope="scope">
                                <div v-for="item in workLevelList">
                                    <div v-if="scope.row.workLevel === item.id">
                                        <span>{{item.name}}</span>
                                    </div>
                                </div>
                            </template>
                        </el-table-column>
                        <el-table-column prop="createUname" label="创建人" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="modifiedUname" label="最后修改人" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="gmtModified" label="最后修改时间" show-overflow-tooltip></el-table-column>
                        <el-table-column fixed="right" label="操作" align="center" width="300">
                            <template slot-scope="scope">
                                <el-button link type="text"  @click="openApproveRuleDialog('查看', scope.row)">查看</el-button>
                                <el-button link type="text"  @click="openApproveRuleDialog('修改', scope.row)">修改</el-button>
                                <el-button link type="text" style="color: red" @click="deleteApproveRule(scope.row)">删除</el-button>
                            </template>
                        </el-table-column>
                    </el-table>
                    <div class="pageBtn">
                        <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="tableData.params.pageIndex" background v-model:page-size="tableData.params.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="tableData.total" class="page-position"> </el-pagination>
                    </div>
                </div>
            </div>
        </div>
        <approve-rule-dialog ref="approveRuleDialogRef" @refreshApproveRule="getApproveRule"></approve-rule-dialog>
    </div>
</template>

<script>
import approveRuleDialog from './components/approveRuleDialog'
import { approveRuleApi } from '../../../../api/approveRule'
import {getDepartmentList} from "../../../../api/departmentManage";
import {safetyInspectionItemName} from "../../../../api/safetySelfInspection";
export default {
    name: 'index',
    components: { approveRuleDialog },
    data(){
        return{
            tableData: {
                approveRuleData: [],
                total: 0,
                loading: false,
                params: {
                    pageIndex: 1,
                    pageSize: 10,
                    searchParams: {
                        ruleName: null,
                        depId: null,
                        workType: null,
                        workLevel: null
                    }
                }
            },
            workTypeList: [
                { id: 1, name: '动火作业' },
                { id: 2, name: '受限空间作业' },
                { id: 3, name: '吊装作业' },
                { id: 4, name: '动土作业' },
                { id: 5, name: '断路作业' },
                { id: 6, name: '高处作业' },
                { id: 7, name: '临时用电作业' },
                { id: 8, name: '盲板抽堵作业' }
            ],
            workLevelList: [
                { id: 3, name: '特级动火作业' },
                { id: 1, name: '一级动火作业' },
                { id: 2, name: '二级动火作业' },
                { id: 7, name: '特级高处作业' },
                { id: 4, name: '一级高处作业' },
                { id: 5, name: '二级高处作业' },
                { id: 6, name: '三级高处作业' },
                { id: 8, name: '一级吊装作业' },
                { id: 9, name: '二级吊装作业' },
                { id: 10, name: '三级吊装作业' },
                { id: 11, name: '抽盲板作业' },
                { id: 12, name: '堵盲板作业' }
            ],
            departmentList: [],
            userList: [],
            deleteList: { ids: [] },
            timeType: [
                { id: 1, name: '分' },
                { id: 2, name: '小时' },
                { id: 3, name: '日' },
                { id: 4, name: '月' },
                { id: 5, name: '年' }
            ]
        }
    },
    created(){
        this.getApproveRule();
        this.getDepartmentData();
        this.getUserData();
    },
    methods:{
        async getApproveRule() {
            let res = await approveRuleApi().getApproveRuleList(this.tableData.params);
            if (res.data.code === '200') {
                this.tableData.approveRuleData = res.data.data;
                this.tableData.total = res.data.total;
            } else {
                this.$message({
                    type: 'warning',
                    message: res.data.message
                });
            }
        },

        openApproveRuleDialog(type, value) {
            this.$refs.approveRuleDialogRef.showApproveRuleDialog(type, value, this.departmentList, this.userList, this.workTypeList);
        },

        async getDepartmentData() {
            let res = await getDepartmentList({pageSize:1000,pageIndex:1})
            if(res.data.code === '200'){
                this.departmentList = res.data.result.result
            }else{
                this.$message({
                    message:res.data.message,
                    type:'warning'
                })
            }
        },

        async getUserData() {
            let res = await safetyInspectionItemName()
            if(res.data.code === '200'){
                this.userList = res.data.result
            }else{
                this.$message({
                    message:res.data.message,
                    type:'warning'
                })
            }
        },

        deleteApproveRule(row) {
            this.$confirm(`此操作将永久删除该审批规则，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            }).then(async () => {
                    let res = await approveRuleApi().deleteApproveRule({ ids: [row.ruleId] });
                    this.deleteList.ids = [];
                    if (res.data.code === '200') {
                        this.$message({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await this.getApproveRule();
                    } else {
                        this.$message({
                            type: 'warning',
                            message: res.data.message
                        });
                    }
                })
                .catch(() => {});
        },

        deleteMoreApproveRule() {
            this.$confirm.confirm(`此操作将永久删除这些审批规则，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await approveRuleApi().deleteApproveRule(this.deleteList);
                    if (res.data.code === '200') {
                        this.$message({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await this.getApproveRule();
                    } else {
                        this.$message({
                            type: 'warning',
                            message: res.data.message
                        });
                    }
                })
                .catch(() => {});
        },

        parseNumber(value, type) {
            if (type === '作业类型') {
                return this.workTypeList.find((item) => item.id === value).name;
            } else if (type === '作业等级') {
                return this.workLevelList.find((item) => item.id == value).name;
            } else {
            }
        },

        handleSelectionChange(val) {
            this.deleteList.ids = val.map((item) => {
                return item.ruleId;
            });
        },

        onHandleSizeChange(val) {
            this.tableData.params.pageSize = val;
            this.getApproveRule();
        },

        onHandleCurrentChange(val) {
            this.tableData.params.pageIndex = val;
            this.getApproveRule();
        },

        reset() {
            this.tableData.params = {
                pageIndex: 1,
                pageSize: 10,
                searchParams: {
                    ruleName: null,
                    depId: null,
                    workType: null,
                    workLevel: null
                }
            };
        }
    },
};
</script>

<style scoped lang="scss">
$homeNavLengh: 8;
.home-container {
    height: calc(100vh - 100px);
    box-sizing: border-box;
    overflow: hidden;
    .homeCard {
        width: 100%;
        padding: 20px;
        box-sizing: border-box;
        background: #fff;
        border-radius: 4px;

        .main-card {
            width: 100%;
            height: 100%;
            .cardTop {
                display: flex;
                align-items: center;
                justify-content: space-between;
                margin-bottom: 20px;
                .mainCardBtn {
                    margin: 0;
                }
            }
            .pageBtn {
                height: 60px;
                display: flex;
                align-items: center;
                justify-content: right;

                .demo-pagination-block + .demo-pagination-block {
                    margin-top: 10px;
                }
                .demo-pagination-block .demonstration {
                    margin-bottom: 16px;
                }
            }
        }
        &:last-of-type {
            height: calc(100% - 100px);
        }
    }
    .el-row {
        display: flex;
        align-items: center;
        margin-bottom: 20px;
        &:last-child {
            margin-bottom: 0;
        }
        .grid-content {
            align-items: center;
            min-height: 36px;
        }

        .topInfo {
            display: flex;
            align-items: center;
            font-size: 16px;
            font-weight: bold;

            & > div {
                white-space: nowrap;
                margin-right: 20px;
            }
        }
    }
}
.stepItem {
    width: 100%;
    display: flex;
    align-items: flex-start;
    margin-bottom: 30px;
    margin-left: 30px;
    padding-bottom: 30px;
    border-left: 2px solid #ccc;
    &:first-of-type {
        margin-top: 30px;
    }
    &:last-of-type {
        margin-bottom: 0;
        border-left: none;
    }
    .stepNum {
        width: 30px;
        height: 30px;
        border-radius: 15px;
        box-sizing: border-box;
        color: #333;
        border: 1px solid #999;
        line-height: 28px;
        text-align: center;
        margin-right: 10px;
        margin-left: -16px;
        margin-top: -30px;
    }
    .stepCard {
        width: 100%;
        margin-top: -30px;

        .box-card {
            width: 100%;
            >>>.el-card__header {
                padding: 10px 15px;
            }
            .card-header {
                width: 100%;
                display: flex;
                justify-content: space-between;
                align-items: center;
                & > div:first-of-type {
                    margin-right: 80px;
                    font-size: 18px;
                    font-weight: bold;
                }
            }
        }
    }
    &:hover .card-header {
        color: #0098f5;
    }
    &:hover .stepNum {
        border: 2px solid #0098f5;
        color: #0098f5;
    }
}
.page-position{
    float: right;
    padding-top: 10px;
}
</style>
